#!/bin/sh
#
# bootmenu_app.sh
# Copyright 2003, Penguru Consulting, LLC
# Written by Jordan Crouse <jordan@penguru.net>
# Released under the GPL - see the LICENSE file for details
#
# Description:
# This script will add an application to the specified bootmenu 
# directory and install it in the specified terminal directories 
# as well

# If you specify a priority, then the application will be inserted
# with that specific priority.  Otherwise, the application will be 
# added as the lowest priority in the directory.

# If you don't specify any tty directories, then the application file
# will just be copied into the application directory.  
#
# Usage:  ./bootmenu_app.sh <directory> <application> <priority> <tty> ...

usage() 
{
    echo -n "Usage:  ./bootmenu_add.sh [directory] [application] [priority]"
    echo " [ttys]"
    echo ""
    echo "* directory is the bootmenu directory you wish to insert the "
    echo "  application in "
    echo ""
    echo "* application is the path of the application file you wish to insert"
    echo ""
    echo "* priority is optional - if specified, the application will be "
    echo "  inserted into the directories at that priority. If omitted,"
    echo "  applications will be added at the lowest priority".
    echo ""
    echo "* ttys is a space delmited list of tty directories to insert the"
    echo "  application into.  Each directory should be specified with the"
    echo "  pattern ttyN where N is a number from 0 to 9."
    echo ""
}

# Add_tty ttydir app priority

add_tty()
{
    # Create the tty directory if it doesn't exist

    if [ ! -d $1 ]; then
	mkdir -p $1
    fi
    
    # Add this to the bottom of the priority list
    # We loop through to ensure that the application isn't already specifed

    if [ $3 -eq -1 ]; then
	FILES=`find $1 -type f -printf "%f\n" | sort`
	POS=-1

	for app in $FILES; do
	    AP=$(echo "$app" | cut -b3-)
	    POS=$(echo "$app" | cut -b1-2)
	    
	    if [ "$AP" == "$2" ]; then 
		echo "$2 already exists for $ttydir.  Skipping..."
		return 0
	    fi
	done
	
	POS=$(expr $POS + 1)

	# Add the directory

        FNAME=$(printf %.2d%s $POS $2)
	touch $1/$FNAME
    else
	# Way more complicated. We need to add the file to the set
	# priority
	
	# So, we need to rename each file that has a value greater
	# than our current priority
	
	FILES=`find $1 -type f -printf "%f\n" | sort -r`
	
	for app in $FILES; do
	    AP=$(echo "$app" | cut -b3-)
	    POS=$(echo "$app" | cut -b1-2)
	    
	    if [ "$AP" == "$2" ]; then 
		echo "$2 already exists in this directory.  Skipping..."
		return 0
	    fi
	    
	    if [ $POS -ge $3 ]; then
		FNAME=$(printf %.2d%s $(expr $POS + 1) $AP)
		mv $1/$app $1/$FNAME
	    fi
	done
	
	FNAME=$(printf %.2d%s $3 $2)
	touch $1/$FNAME
    fi   
}
	    		  
PRIO=-1
TTYS=

### Read the arguments

if [ $# -lt 2 ]; then
	usage; exit 1;
fi

DIR=$1
AFILE=$2
APP=`basename $AFILE`

shift 2

if [ $# -gt 0 ]; then 
	VAL=$(echo $1 | cut -b1-3)

	if [ "$VAL" != "tty" ]; then
	    PRIO=$1
	    shift
	 fi
fi

while [ $# -gt 0 ]; do
    VAL=$(echo $1 | cut -b1-3)
    if [ "$VAL" == "tty" ]; then	
	TTYS=$(echo "$TTYS" "$1")
    else
	echo "$1 is an invalid tty.  Skipping..."
    fi
    
    shift;
done

## Create the apps directory if need be

if [ ! -d "$DIR/apps" ]; then
    mkdir -p $DIR/apps
fi

## Add the application to the apps directory

if [ ! -f "$DIR/apps/$APP" ]; then
    cp $AFILE $DIR/apps/$APP
else
    echo "$AFILE already exists in $DIR/apps.  Skipping..."
fi

## Add the application with the specified priority to each tty

for tty in $TTYS; do 
    add_tty $DIR/$tty $APP $PRIO
done





    





