#ifndef BOOTMENU_H_
#define BOOTMENU_H_

/*
 * Copyright (C) 2003, Penguru Consulting, LLC
 * Written by:  Jordan Crouse (jordan@penguru.net)
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
 *
 */

#include <sys/types.h>

/* This number was picked so that the bootmenu would only need 1 digit */
#define MAX_APPS 9   

/* This should be enough. */
#define MAX_TTYS 10  

/* Logging.  Either use my local logger or syslog (selected at compile time) */

#ifdef SYSLOG

#include <syslog.h>

#define OPENLOG()           openlog("bootmenu", LOG_CONS, LOG_DAEMON)
#define LOG(fmt, args...)   syslog(LOG_WARNING, fmt, ##args)
#define CLOSELOG()          closelog();
#define DEBUG(fmt, args...) syslog(LOG_DEBUG, fmt, ##args)

#else

void open_mylog(void);
void mylog(char *, ...);
void close_mylog(void);

#define OPENLOG()           open_mylog()
#define LOG(fmt, args...)   mylog(fmt, ##args)
#define CLOSELOG()          close_mylog()
#define DEBUG(fmt, args...) printf(fmt, ##args) 

#endif

struct app {
  char *name;  /* Name of the app (ie, picogui, opie) */
  char *title; /* The pretty title for the bootmenu */
  char *command; /* The actual app / script to run (with arguments) */  
  pid_t pid; /* The current running pid of the app */
};

struct tty {
  int tty;          /* The tty number */
  pid_t pid;        /* The current pid running on the tty */
  int spawn;        /* Number of times this thing has spawned */
  time_t timestamp; /* A timestamp is taken every 5 spawns */
  struct app *app;  /* The current app running on the tty (0 for bootmenu) */
};

struct config {
  char *logfile;
  char *plugin;
  char *plugindir;
};

/* From TinyLogin getty.  This makes life much easier */
/* Copyright (C) 1999-2003 Erik Andersen <andersen@codepoet.org> */

#define CTL(x)	 (x ^ 0100)	/* Assumes ASCII dialect */
#define	CR	 CTL('M')	/* carriage return */
#define	NL	 CTL('J')	/* line feed */
#define	BS	 CTL('H')	/* back space */
#define	DEL	 CTL('?')	/* delete */

/* This is a simple structure used to do really quick and dirty config file parsing */

struct keywords {
  char *keyword;
  unsigned short offset;
};

/* This will define a single line in an array of struct keywords.  It can
   figure out the offset and size without bothering the user too much 
*/

#define KEYWORD(str, st, field)  { str, offsetof(st, field) }

int parse_file(const char *, struct keywords *, void *);

struct app *do_bootmenu(struct app *);

#ifdef PLUGINS
int init_plugin(const char *);
#endif

#endif
