/*
 * bootmenu - A program for spawning apps on a TTY
 * Developed especially for booting a graphical engine
 * but I guess it could be used for anything
 *
 * Copyright (C) 2003, Penguru Consulting, LLC
 * Written by:  Jordan Crouse (jordan@penguru.net)
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
 *
 */

/* Just in case you don't want to use the syslog, you can use this code instead.
   I use this just because I don't want to encumber my syslog while I'm debugging.
   If you don't want this file included (and I don't blame you), just set USE_SYSLOG=y
   int the config.
*/

#include <stdio.h>
#include <string.h>
#include <errno.h>
#include <stdarg.h>
#include <time.h>

#include "bootmenu.h"

#define _LOGFILE "/tmp/bootmenu.log"

extern struct config bootmenu_config;
static FILE *log = 0;

void open_mylog(void) {
  if (log) return;

  if (bootmenu_config.logfile)
    log = fopen(bootmenu_config.logfile, "a+");

  if (!log) log = fopen(_LOGFILE, "a+");

  if (!log) 
    fprintf(stderr, "bootmenu: Error opening the logger [%s]\n", strerror(errno));
}

 
void mylog(char *format, ...) {
  char date[25];

  va_list ap;
  time_t now = time(0);
  struct tm *tm = localtime(&now);

  if (!log) return;

  bzero(date, sizeof(date));
  strftime(date, sizeof(date), "%b %e %l:%M:%S %p", tm);

  fprintf(log, "BOOTMENU %s ", date);

  va_start(ap, format);
  vfprintf(log, format, ap);
  va_end(ap);

  fflush(log);
}

void close_mylog(void) {
  if (log) fclose(log);
}
