/*
 * bootmenu - A program for spawning apps on a TTY
 * Developed especially for booting a graphical engine
 * but I guess it could be used for anything
 *
 * Copyright (C) 2003, Penguru Consulting, LLC
 * Written by:  Jordan Crouse (jordan@penguru.net)
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
 *
 */

#include <stdio.h>
#include <unistd.h>
#include <dlfcn.h>
#include <fcntl.h>
#include "bootmenu.h"

#ifndef _PLUGINDIR
#define _PLUGINDIR "/usr/share/bootmenu"
#endif

extern struct config bootmenu_config;

/* These are the standard plugin dirs to search if nothing was specified */

static char *plugin_dirs[] = { 
  ".",
  _PLUGINDIR,   
  0 
};
 
typedef struct app * (*FUNC)(struct app *);

static struct {
  void *handle;
  FUNC bootmenu;
} plugin;


static int load_plugin(const char *name) {
  
  char path[256];
  int dir = 0;

  if (bootmenu_config.plugindir) {
    sprintf(path, "%s/%s.so", bootmenu_config.plugindir, name);
    if (!access(path, R_OK)) goto load_plugin;
  }

  for(dir = 0; plugin_dirs[dir]; dir++) {
    sprintf(path, "%s/%s.so", plugin_dirs[dir], name);
    if (!access(path, R_OK)) goto load_plugin;
  }

  return -1;

 load_plugin:
  
  plugin.handle = dlopen(path, RTLD_GLOBAL | RTLD_NOW);
  if (!plugin.handle) {
    LOG("Unable to load the plugin [%s] [%s]\n", name, dlerror());
    return -1;
  }

  /* Get the hook */
  
  plugin.bootmenu = (FUNC) dlsym(plugin.handle, "plugin_bootmenu");
  
  if (!plugin.bootmenu) {
    dlclose(plugin.handle);
    plugin.handle = 0;
    return -1;
  }
  
  LOG("Successfully loaded menu plugin [%s]\n", name);
  return 0;
}

int init_plugin(const char *name) {
    
  /* If a name was specified, then try to load it */

  if (name)
    if (!load_plugin(name)) return 0;  /* Success */
  
  /* Otherwise, just load the default plugin */
  if (!load_plugin(DEFAULT_PLUGIN)) return 0;
  
  return -1;  /* Unable to load anything */
}

/* This is the standard function called to show the bootmenu */

struct app * do_bootmenu(struct app *app) {
  if (plugin.bootmenu) return plugin.bootmenu(app);
  return 0;
}
  

  
  

      


		 
  
